docs.rs failed to build squire-sqlite3-sys-0.0.1-alpha.6
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
squire-sqlite3-sys-0.0.1-alpha.5
squire-sqlite3-sys
Squire is a crate for embedding SQLite in Rust. This squire-sqlite3-sys crate links SQLite into the application, exposing the C API of SQLite to Rust.
Users of Squire don't need to interact with this crate directly, and can treat it as an implementation detail.
External Users
By default, squire-sqlite3-sys ships a predefined set of extern "C" declarations for SQLite. This includes only the API’s actually used by Squire.
To instead generate complete bindings based on the installed or bundled sqlite3.h header, activate the bindgen feature.