squire-sqlite3-sys 0.0.1-alpha.1

External FFI bindings for the SQLite C API
docs.rs failed to build squire-sqlite3-sys-0.0.1-alpha.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: squire-sqlite3-sys-0.0.1-alpha.5